@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2007   Alex Shulgin
+ * Copyright (C) 2007,2008   Alex Shulgin
  *
- * This file is part of png++ the C++ wrapper for libpng.  Png++ is free
+ * This file is part of png++ the C++ wrapper for libpng.  PNG++ is free
  * software; the exact copying conditions are as follows:
  *
  * Redistribution and use in source and binary forms, with or without
@@ -48,7 +48,7 @@ namespace png
      * way to get starting address of the row for packed and unpacked
      * row types.
      *
-     * Not implemented -- see specializations.
+     * Not implemented--see specializations.
      */
     template< typename row > class row_traits;
 
@@ -311,8 +311,8 @@ namespace png
 
             packed_pixel_proxy& operator=(pixel p)
             {
-                this->m_ref = this->m_ref
-                    & ~(pixel::get_bit_mask() << this->m_shift)
+                this->m_ref = (this->m_ref
+                    & ~(pixel::get_bit_mask() << this->m_shift))
                     | (p << this->m_shift);
 
                 return *this;
